==> zio-aws-ec2_2.12-5.17.161.1-sources.jar: zio/aws/ec2/model/CreateInstanceEventWindowResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateInstanceEventWindowResponse(
    instanceEventWindow: Option[zio.aws.ec2.model.InstanceEventWindow] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse = {
    import CreateInstanceEventWindowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
      .builder()
      .optionallyWith(instanceEventWindow.map(value => value.buildAwsValue()))(
        _.instanceEventWindow
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CreateInstanceEventWindowResponse.ReadOnly =
    zio.aws.ec2.model.CreateInstanceEventWindowResponse.wrap(buildAwsValue())
}
object CreateInstanceEventWindowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateInstanceEventWindowResponse =
      zio.aws.ec2.model.CreateInstanceEventWindowResponse(
        instanceEventWindow.map(value => value.asEditable)
      )
    def instanceEventWindow
        : Option[zio.aws.ec2.model.InstanceEventWindow.ReadOnly]
    def getInstanceEventWindow
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceEventWindow.ReadOnly] =
      AwsError.unwrapOptionField("instanceEventWindow", instanceEventWindow)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
  ) extends zio.aws.ec2.model.CreateInstanceEventWindowResponse.ReadOnly {
    override val instanceEventWindow
        : Option[zio.aws.ec2.model.InstanceEventWindow.ReadOnly] = scala
      .Option(impl.instanceEventWindow())
      .map(value => zio.aws.ec2.model.InstanceEventWindow.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
  ): zio.aws.ec2.model.CreateInstanceEventWindowResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.12-5.19.7.1-sources.jar: zio/aws/ec2/model/CreateInstanceEventWindowResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateInstanceEventWindowResponse(
    instanceEventWindow: Optional[zio.aws.ec2.model.InstanceEventWindow] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse = {
    import CreateInstanceEventWindowResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
      .builder()
      .optionallyWith(instanceEventWindow.map(value => value.buildAwsValue()))(
        _.instanceEventWindow
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CreateInstanceEventWindowResponse.ReadOnly =
    zio.aws.ec2.model.CreateInstanceEventWindowResponse.wrap(buildAwsValue())
}
object CreateInstanceEventWindowResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateInstanceEventWindowResponse =
      zio.aws.ec2.model.CreateInstanceEventWindowResponse(
        instanceEventWindow.map(value => value.asEditable)
      )
    def instanceEventWindow
        : Optional[zio.aws.ec2.model.InstanceEventWindow.ReadOnly]
    def getInstanceEventWindow
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceEventWindow.ReadOnly] =
      AwsError.unwrapOptionField("instanceEventWindow", instanceEventWindow)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
  ) extends zio.aws.ec2.model.CreateInstanceEventWindowResponse.ReadOnly {
    override val instanceEventWindow
        : Optional[zio.aws.ec2.model.InstanceEventWindow.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instanceEventWindow())
        .map(value => zio.aws.ec2.model.InstanceEventWindow.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateInstanceEventWindowResponse
  ): zio.aws.ec2.model.CreateInstanceEventWindowResponse.ReadOnly = new Wrapper(
    impl
  )
}
